Learn R Programming

EpiTest (version 1.0.0)

pchisqmix: Chi-Squared Mixtures Distribution Function

Description

The approximate null distribution of a likelihood ratio for 2 nested mixed models, where both fixed and random effects are tested simultaneously, is a very specific mixture of chi-square distributions. It depends on both the number of random effects and the number of fixed effects to be tested simultaneously. Note that this function is a copy of the pchisqmix function of the TcGSA package.

Usage

pchisqmix(quant, s, q, lower.tail = TRUE)

Value

a probability.

Arguments

quant

a quantile

s

number of fixed effects to be tested

q

number of random effects to be tested

lower.tail

logical. if TRUE (default), probabilities are \(P[X<=x]\), otherwise \(P[X>x]\).